# Changelog

## [1.0.4](https://github.com/CoreySpohn/coronalyze/compare/v1.0.3...v1.0.4) (2026-01-27)


### Bug Fixes

* Clean up yippy call ([49b3a8a](https://github.com/CoreySpohn/coronalyze/commit/49b3a8a0def1278a4041c50e68c70268d8be688a))
* Cleaning out unnecessary dependencies ([ad20c4f](https://github.com/CoreySpohn/coronalyze/commit/ad20c4fcee093233792f7b7ff7de56077266c3c4))
* Mask out points in the snr_map at small separations where the results are undefined ([d094c88](https://github.com/CoreySpohn/coronalyze/commit/d094c88b71821bcf90a2a801adbf37ec0d069c8a))
* Updating tests to fix error hopefully ([7c8e139](https://github.com/CoreySpohn/coronalyze/commit/7c8e1399ae7789bd58638f3574cb29e6dcf8b91e))

## [1.0.3](https://github.com/CoreySpohn/coronalyze/compare/v1.0.2...v1.0.3) (2026-01-27)


### Bug Fixes

* Version management fix ([35f9175](https://github.com/CoreySpohn/coronalyze/commit/35f9175fc6699c684e5939f68454fbc3184ea1ce))

## [1.0.2](https://github.com/CoreySpohn/coronalyze/compare/v1.0.1...v1.0.2) (2026-01-27)


### Bug Fixes

* Revert name back to coronalyze ([8dc5d93](https://github.com/CoreySpohn/coronalyze/commit/8dc5d9368db3dfeb69e7b270c9f6fb959715d5fe))

## [1.0.1](https://github.com/CoreySpohn/coronalyze/compare/v1.0.0...v1.0.1) (2026-01-26)


### Bug Fixes

* Update the wheel targets to avoid data files ([cd4299d](https://github.com/CoreySpohn/coronalyze/commit/cd4299d0e12045fdb64f7418f63ee0b4bdffe269))

## 1.0.0 (2026-01-26)


### Features

* Add literally everything ([60a8394](https://github.com/CoreySpohn/coronalyze/commit/60a83946f340c26c99d503174a11eebd2f7ae434))
* Introduce the `coronalyze` library for JAX-based coronagraphic image post-processing, including aperture photometry and SNR calculations, along with project infrastructure. ([053595f](https://github.com/CoreySpohn/coronalyze/commit/053595fc5936025493872363e35ae683a4561bde))
